@@ -4,9 +4,9 @@ from . import helpers
 
 
 @shared_task(time_limit=86400)
-def task_checksum_file_post_save(checksumfile_id):
+def task_checksum_file_post_save(checksumfile_pk):
     from rgd.models import ChecksumFile
 
-    obj = ChecksumFile.objects.get(id=checksumfile_id)
+    obj = ChecksumFile.objects.get(pk=checksumfile_pk)
 
     helpers._run_with_failure_reason(obj, obj.post_save_job)
